@@ -237,6 +237,7 @@ typedef enum {
     S2N_ERR_LIBCRYPTO_VERSION_NUMBER_MISMATCH,
     S2N_ERR_LIBCRYPTO_VERSION_NAME_MISMATCH,
     S2N_ERR_OSSL_PROVIDER,
+    S2N_ERR_BAD_HEX,
     S2N_ERR_TEST_ASSERTION,
     S2N_ERR_T_INTERNAL_END,
 
@@ -328,6 +329,7 @@ typedef enum {
     S2N_ERR_KTLS_KEY_LIMIT,
     S2N_ERR_SECURITY_POLICY_INCOMPATIBLE_CERT,
     S2N_ERR_INVALID_SERIALIZED_CONNECTION,
+    S2N_ERR_TOO_MANY_CAS,
     S2N_ERR_T_USAGE_END,
 } s2n_error;
 
