@@ -9,10 +9,26 @@ banner()
     echo "+---------------------------------------------------------+"
 }
 
+function libcrypto_alias {
+    local libcrypto_name=$1
+    local libcrypto_binary_path=$2
+    if [[ -f $libcrypto_binary_path ]]; then
+      alias $libcrypto_name=$libcrypto_binary_path
+      echo "Libcrypto binary $libcrypto_binary_path available as $libcrypto_name"
+    else
+      banner "Could not find libcrypto $libcrypto_binary_path for alias"
+    fi
+}
+libcrypto_alias openssl102 "${OPENSSL_1_0_2_INSTALL_DIR}/bin/openssl"
+libcrypto_alias openssl111 "${OPENSSL_1_1_1_INSTALL_DIR}/bin/openssl"
+libcrypto_alias openssl30 "${OPENSSL_3_0_INSTALL_DIR}/bin/openssl"
+libcrypto_alias bssl "${AWSLC_INSTALL_DIR}/bin/bssl"
+libcrypto_alias libressl "${LIBRESSL_INSTALL_DIR}/bin/openssl"
+#No need to alias gnutls because it is included in common_packages (see flake.nix).
 
 function clean {
     banner "Cleanup ./build"
-    rm -rf ./build
+    rm -rf ./build ./s2n_head
 }
 
 function configure {
@@ -31,6 +47,10 @@ function build {
     banner "Running Build"
     javac tests/integrationv2/bin/SSLSocketClient.java
     cmake --build ./build -j $(nproc)
+    # Build s2n from HEAD
+    if [[ -z "${S2N_KTLS_TESTING_EXPECTED}" ]]; then
+        $SRC_ROOT/codebuild/bin/install_s2n_head.sh $(mktemp -d)
+    fi
 }
 
 function unit {
@@ -44,21 +64,16 @@ function unit {
 function integ {
     if [ "$1" == "help" ]; then
         echo "The following tests are not supported:"
-        echo " - cross_compatibility"
-        echo "    This test depends on s2nc_head and s2nd_head. To run"
-        echo "    the test build s2n-tls from the main branch on github."
-        echo "    Change the names of s2n[cd] to s2n[cd]_head and add those"
-        echo "    binaries to \$PATH."
         echo "- renegotiate_apache"
         echo "   This test requires apache to be running. See codebuild/bin/s2n_apache.sh"
         echo "    for more info."
         return
     fi
     if [[ -z "$1" ]]; then
-        banner "Running all integ tests except cross_compatibility, renegotiate_apache."
+        banner "Running all integ tests except renegotiate_apache."
         (cd $SRC_ROOT/build; ctest -L integrationv2 -E "(integrationv2_cross_compatibility|integrationv2_renegotiate_apache)" --verbose)
     else
-        banner "Warning: cross_compatibility & renegotiate_apache are not supported in nix for various reasons integ help for more info."
+        banner "Warning: renegotiate_apache is not supported in nix for various reasons integ help for more info."
         for test in $@; do
             ctest --test-dir ./build -L integrationv2 --no-tests=error --output-on-failure -R "$test" --verbose
             if [ "$?" -ne 0 ]; then
@@ -118,7 +133,7 @@ function do-clang-format {
 
 function test_toolchain_counts {
     # This is a starting point for a unit test of the devShell.
-    # The choosen S2N_LIBCRYPTO should be 2, and the others should be zero.
+    # The chosen S2N_LIBCRYPTO should be 2, and the others should be zero.
     banner "Checking the CMAKE_INCLUDE_PATH for libcrypto counts"
     echo $CMAKE_INCLUDE_PATH|gawk 'BEGIN{RS=":"; o10=0; o11=0; o3=0;awslc=0;libre=0}
       /openssl-3.0/{o3++}
@@ -136,6 +151,7 @@ function test_toolchain_counts {
     echo -e "Nix pytest:\t $(which pytest|grep -c '/nix/store')"
     echo -e "Nix sslyze:\t $(which sslyze|grep -c '/nix/store')"
     echo -e "python nassl:\t $(pip freeze|grep -c 'nassl')"
+    echo -e "valgrind:\t $(valgrind --version|grep -c 'valgrind-3.19.0')"
 }
 
 function test_nonstandard_compilation {
